==> pygenesis-1.0.0.tar.gz: pygenesis-1.0.0/README.md <==
# PyGenesis

Python package repository template

You can find **Full Project Documentation** [here][documentation_path]

<hr>

#### Workflows
[![Tests](https://github.com/libresource/pygenesisactions/workflows/run-tests.yml/badge.svg?branch=main)](https://github.com/libresource/pygenesisactions/workflows/run-tests.yml)
[![Pylint](https://github.com/libresource/pygenesisactions/workflows/lint.yml/badge.svg?branch=main)](https://github.com/libresource/pygenesisactions/workflows/lint.yml)

#### Package
[![Version](https://img.shields.io/pypi/v/pygenesis.svg)](https://pypi.python.org/pypi/pygenesis/)
[![Development Status](https://img.shields.io/pypi/status/pygenesis.svg)](https://pypi.python.org/pypi/pygenesis)
[![Python version](https://img.shields.io/pypi/pyversions/pygenesis.svg)](https://pypi.python.org/pypi/pygenesis/)
[![License](https://img.shields.io/pypi/l/pygenesis)](https://github.com/libresource/pygenesisblob/main/LICENSE)
[![Wheel](https://img.shields.io/pypi/wheel/pygenesis.svg)](https://pypi.python.org/pypi/pygenesis/)

#### Support
[![Documentation](https://img.shields.io/badge/docs-0094FF.svg)][documentation_path]
[![Discussions](https://img.shields.io/badge/discussions-ff0068.svg)](https://github.com/libresource/pygenesisdiscussions/)
[![Issues](https://img.shields.io/badge/issues-11AE13.svg)](https://github.com/libresource/pygenesisissues/)

#### Downloads
[![Day Downloads](https://img.shields.io/pypi/dd/pygenesis)](https://pepy.tech/project/pygenesis)
[![Week Downloads](https://img.shields.io/pypi/dw/pygenesis)](https://pepy.tech/project/pygenesis)
[![Month Downloads](https://img.shields.io/pypi/dm/pygenesis)](https://pepy.tech/project/pygenesis)
[![All Downloads](https://img.shields.io/pepy/dt/pygenesis)](https://pepy.tech/project/pygenesis)

#### Languages
[![Languages](https://img.shields.io/github/languages/count/libresource/pygenesis)](https://github.com/libresource/pygenesis)
[![Top Language](https://img.shields.io/github/languages/top/libresource/pygenesis)](https://github.com/libresource/pygenesis)

#### Development
- [![Release date](https://img.shields.io/github/release-date/libresource/pygenesis
)](https://github.com/libresource/pygenesisreleases)
[![Last Commit](https://img.shields.io/github/last-commit/libresource/pygenesismain
)](https://github.com/libresource/pygenesis)
- [![Issues](https://img.shields.io/github/issues/libresource/pygenesis
)](https://github.com/libresource/pygenesisissues/)
[![Closed Issues](https://img.shields.io/github/issues-closed/libresource/pygenesis
)](https://github.com/libresource/pygenesisissues/)
- [![Pull Requests](https://img.shields.io/github/issues-pr/libresource/pygenesis
)](https://github.com/libresource/pygenesispulls)
[![Closed Pull Requests](https://img.shields.io/github/issues-pr-closed-raw/libresource/pygenesis
)](https://github.com/libresource/pygenesispulls)
- [![Discussions](https://img.shields.io/github/discussions/libresource/pygenesis
)](https://github.com/libresource/pygenesisdiscussions/)

[//]: # (#### Repository Stats)

[//]: # ([![Stars]&#40;https://img.shields.io/github/stars/libresource/pygenesis)

[//]: # (&#41;]&#40;https://github.com/libresource/pygenesis&#41;)

[//]: # ([![Contributors]&#40;https://img.shields.io/github/contributors/libresource/pygenesis)

[//]: # (&#41;]&#40;https://github.com/libresource/pygenesisgraphs/contributors&#41;)

[//]: # ([![Forks]&#40;https://img.shields.io/github/forks/libresource/pygenesis)

[//]: # (&#41;]&#40;https://github.com/libresource/pygenesis&#41;)

<hr>

## Menu

- [Mission](#mission)
- [Open Source Project](#open-source-project)
- [Features](#features)
- [Requirements](#requirements)
- [Development Status](#development-status)
- [Install](#install)
- [Quickstart](#quickstart)
- [Contributing](#contributing)

## Mission

PyGenesis is a comprehensive Python package template designed to kickstart your projects instantly. 
With a clean and organized structure, it provides a hassle-free starting point for developers. 
Effortlessly begin your Python endeavors, focusing on your code, not the setup. Jumpstart your creativity with PyGenesis.

## Open Source Project

This is the open source project with [MIT license](LICENSE). 
Be free to use, fork, clone and contribute.

## Features

- This README (Change it for your python project)
- This template base on [libresource/open-source-checklist](https://github.com/libresource/open-source-checklist). 
It contains may useful files for open source project: ([CHECKLIST.md](CHECKLIST.md), [CONTRIBUTING.md](CONTRIBUTING.md), 
[CODE_OF_CONDUCT.md](CODE_OF_CONDUCT.md), and much more). 
- `setup.py` for build your package
- `requirements.txt` and `dev-requirements.txt`
- `Makefile` with main commands to work with the project
  - run tests
  - calculate coverage
  - lint
  - build and install package
  - generate autodocumentation
  - others
- GitHub workflows 
  - generate documentation
  - run tests with coverage
  - run linter
  - publish your package in PyPi
  - greetings for new contributors

## Requirements

- pytest, pytest-cov, pylint, yamllint, sphinx, sphinx_rtd_theme
- See more in [Full Documentation](https://pygenesis.libresource.info/about.html#requirements)

## Development Status

- Package already available on [PyPi](https://pypi.org/project/pygenesis/)
- See more in [Full Documentation](https://pygenesis.libresource.info/about.html#development-status)

## Install

### with pip

```commandline
pip install pygenesis
```

See more in [Full Documentation](https://pygenesis.libresource.info/install.html)

## Quickstart

```python
from pygenesis import info

print(info())
```

### More examples in [Full Documentation][documentation_path]

## Contributing

You are welcome! To easy start please check:
- [Full Documentation][documentation_path]
- [Contributing](CONTRIBUTING.md)
- [Developer Documentation](https://pygenesis.libresource.info/dev_documentation.html)
- [Code of Conduct](CODE_OF_CONDUCT.md)
- [Security Policy](SECURITY.md)
- [Governance](GOVERNANCE.md)
- [Support](SUPPORT.md)

[documentation_path]: https://pygenesis.libresource.info

==> pygenesis-1.0.1.tar.gz: pygenesis-1.0.1/README.md <==
# PyGenesis

Python package repository template

You can find **Full Project Documentation** [here][documentation_path]

<hr>

#### Workflows
[![Tests](https://github.com/libresource/pygenesis/actions/workflows/run-tests.yml/badge.svg?branch=main)](https://github.com/libresource/pygenesis/actions/workflows/run-tests.yml)
[![Pylint](https://github.com/libresource/pygenesis/actions/workflows/lint.yml/badge.svg?branch=main)](https://github.com/libresource/pygenesis/actions/workflows/lint.yml)

#### Package
[![Version](https://img.shields.io/pypi/v/pygenesis.svg)](https://pypi.python.org/pypi/pygenesis/)
[![Development Status](https://img.shields.io/pypi/status/pygenesis.svg)](https://pypi.python.org/pypi/pygenesis)
[![Python version](https://img.shields.io/pypi/pyversions/pygenesis.svg)](https://pypi.python.org/pypi/pygenesis/)
[![License](https://img.shields.io/pypi/l/pygenesis)](https://github.com/libresource/pygenesisblob/main/LICENSE)
[![Wheel](https://img.shields.io/pypi/wheel/pygenesis.svg)](https://pypi.python.org/pypi/pygenesis/)

#### Support
[![Documentation](https://img.shields.io/badge/docs-0094FF.svg)][documentation_path]
[![Discussions](https://img.shields.io/badge/discussions-ff0068.svg)](https://github.com/libresource/pygenesis/discussions/)
[![Issues](https://img.shields.io/badge/issues-11AE13.svg)](https://github.com/libresource/pygenesis/issues/)

#### Downloads
[![Day Downloads](https://img.shields.io/pypi/dd/pygenesis)](https://pepy.tech/project/pygenesis)
[![Week Downloads](https://img.shields.io/pypi/dw/pygenesis)](https://pepy.tech/project/pygenesis)
[![Month Downloads](https://img.shields.io/pypi/dm/pygenesis)](https://pepy.tech/project/pygenesis)
[![All Downloads](https://img.shields.io/pepy/dt/pygenesis)](https://pepy.tech/project/pygenesis)

#### Languages
[![Languages](https://img.shields.io/github/languages/count/libresource/pygenesis)](https://github.com/libresource/pygenesis)
[![Top Language](https://img.shields.io/github/languages/top/libresource/pygenesis)](https://github.com/libresource/pygenesis)

#### Development
- [![Release date](https://img.shields.io/github/release-date/libresource/pygenesis
)](https://github.com/libresource/pygenesis/releases)
[![Last Commit](https://img.shields.io/github/last-commit/libresource/pygenesis/main
)](https://github.com/libresource/pygenesis)
- [![Issues](https://img.shields.io/github/issues/libresource/pygenesis
)](https://github.com/libresource/pygenesis/issues/)
[![Closed Issues](https://img.shields.io/github/issues-closed/libresource/pygenesis
)](https://github.com/libresource/pygenesis/issues/)
- [![Pull Requests](https://img.shields.io/github/issues-pr/libresource/pygenesis
)](https://github.com/libresource/pygenesis/pulls)
[![Closed Pull Requests](https://img.shields.io/github/issues-pr-closed-raw/libresource/pygenesis
)](https://github.com/libresource/pygenesis/pulls)
- [![Discussions](https://img.shields.io/github/discussions/libresource/pygenesis
)](https://github.com/libresource/pygenesis/discussions/)

[//]: # (#### Repository Stats)

[//]: # ([![Stars]&#40;https://img.shields.io/github/stars/libresource/pygenesis)

[//]: # (&#41;]&#40;https://github.com/libresource/pygenesis&#41;)

[//]: # ([![Contributors]&#40;https://img.shields.io/github/contributors/libresource/pygenesis)

[//]: # (&#41;]&#40;https://github.com/libresource/pygenesisgraphs/contributors&#41;)

[//]: # ([![Forks]&#40;https://img.shields.io/github/forks/libresource/pygenesis)

[//]: # (&#41;]&#40;https://github.com/libresource/pygenesis&#41;)

<hr>

## Menu

- [Mission](#mission)
- [Open Source Project](#open-source-project)
- [Features](#features)
- [Requirements](#requirements)
- [Development Status](#development-status)
- [Install](#install)
- [Quickstart](#quickstart)
- [Contributing](#contributing)

## Mission

PyGenesis is a comprehensive Python package template designed to kickstart your projects instantly. 
With a clean and organized structure, it provides a hassle-free starting point for developers. 
Effortlessly begin your Python endeavors, focusing on your code, not the setup. Jumpstart your creativity with PyGenesis.

## Open Source Project

This is the open source project with [MIT license](LICENSE). 
Be free to use, fork, clone and contribute.

## Features

- This README (Change it for your python project)
- This template base on [libresource/open-source-checklist](https://github.com/libresource/open-source-checklist). 
It contains may useful files for open source project: ([CHECKLIST.md](CHECKLIST.md), [CONTRIBUTING.md](CONTRIBUTING.md), 
[CODE_OF_CONDUCT.md](CODE_OF_CONDUCT.md), and much more). 
- `setup.py` for build your package
- `requirements.txt` and `dev-requirements.txt`
- `Makefile` with main commands to work with the project
  - run tests
  - calculate coverage
  - lint
  - build and install package
  - generate autodocumentation
  - others
- GitHub workflows 
  - generate documentation
  - run tests with coverage
  - run linter
  - publish your package in PyPi
  - greetings for new contributors

## Requirements

- pytest, pytest-cov, pylint, yamllint, sphinx, sphinx_rtd_theme
- See more in [Full Documentation](https://pygenesis.libresource.info/about.html#requirements)

## Development Status

- Package already available on [PyPi](https://pypi.org/project/pygenesis/)
- See more in [Full Documentation](https://pygenesis.libresource.info/about.html#development-status)

## Install

### with pip

```commandline
pip install pygenesis
```

See more in [Full Documentation](https://pygenesis.libresource.info/install.html)

## Quickstart

```python
from pygenesis import info

print(info())
```

### More examples in [Full Documentation][documentation_path]

## Contributing

You are welcome! To easy start please check:
- [Full Documentation][documentation_path]
- [Contributing](CONTRIBUTING.md)
- [Developer Documentation](https://pygenesis.libresource.info/dev_documentation.html)
- [Code of Conduct](CODE_OF_CONDUCT.md)
- [Security Policy](SECURITY.md)
- [Governance](GOVERNANCE.md)
- [Support](SUPPORT.md)

[documentation_path]: https://pygenesis.libresource.info
